@@ -7,13 +7,12 @@ use Path::Tiny ();
 use Carp ();
 use File::chdir;
 use JSON::PP ();
-use Env qw( @PATH );
-use Env qw( @PKG_CONFIG_PATH );
+use Env qw( @PATH @PKG_CONFIG_PATH );
 use Config ();
 use Alien::Build::Log;
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '2.33'; # VERSION
+our $VERSION = '2.47'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -30,6 +29,7 @@ sub new
     runtime_prop => {
       alien_build_version => $Alien::Build::VERSION || 'dev',
     },
+    plugin_instance_prop => {},
     bin_dir => [],
     pkg_config_path => [],
     aclocal_path => [],
@@ -165,8 +165,9 @@ sub resume
   my(undef, $alienfile, $root) = @_;
   my $h = JSON::PP::decode_json(_path("$root/state.json")->slurp);
   my $self = Alien::Build->load("$alienfile", @{ $h->{args} });
-  $self->{install_prop} = $h->{install};
-  $self->{runtime_prop} = $h->{runtime};
+  $self->{install_prop}         = $h->{install};
+  $self->{plugin_instance_prop} = $h->{plugin_instance};
+  $self->{runtime_prop}         = $h->{runtime};
   $self;
 }
 
@@ -184,6 +185,14 @@ sub install_prop
 }
 
 
+sub plugin_instance_prop
+{
+  my($self, $plugin) = @_;
+  my $instance_id = $plugin->instance_id;
+  $self->{plugin_instance_prop}->{$instance_id} ||= {};
+}
+
+
 sub runtime_prop
 {
   shift->{runtime_prop};
@@ -220,9 +229,10 @@ sub checkpoint
   my $root = $self->root;
   _path("$root/state.json")->spew(
     JSON::PP->new->pretty->canonical(1)->ascii->encode({
-      install => $self->install_prop,
-      runtime => $self->runtime_prop,
-      args    => $self->{args},
+      install         => $self->install_prop,
+      runtime         => $self->runtime_prop,
+      plugin_instance => $self->{plugin_instance_prop},
+      args            => $self->{args},
     })
   );
   $self;
@@ -428,7 +438,23 @@ sub probe
             $CWD = $self->root;
           },
           ok       => 'system',
-          continue => sub { $_[0] ne 'system' },
+          continue => sub {
+            if($_[0] eq 'system')
+            {
+              foreach my $name (qw( probe_class probe_instance_id ))
+              {
+                if(exists $self->hook_prop->{$name} && defined $self->hook_prop->{$name})
+                {
+                  $self->install_prop->{"system_$name"} = $self->hook_prop->{$name};
+                }
+              }
+              return undef;
+            }
+            else
+            {
+              return 1;
+            }
+          },
         },
         'probe',
       );
@@ -546,8 +572,8 @@ sub download
 
 sub fetch
 {
-  my($self, $url) = @_;
-  $self->_call_hook( 'fetch' => $url );
+  my $self = shift;
+  $self->_call_hook( 'fetch' => @_ );
 }
 
 
@@ -1123,7 +1149,6 @@ package Alien::Build::TempDir;
 # redundant).  Happily both are private classes, and either are able to
 # rename, if a good name can be thought of.
 
-use Path::Tiny qw( path );
 use overload '""' => sub { shift->as_string }, bool => sub { 1 }, fallback => 1;
 use File::Temp qw( tempdir );
 
@@ -1131,9 +1156,9 @@ sub new
 {
   my($class, $build, $name) = @_;
   my $root = $build->install_prop->{root};
-  path($root)->mkpath unless -d $root;
+  Path::Tiny->new($root)->mkpath unless -d $root;
   bless {
-    dir => path(tempdir( "${name}_XXXX", DIR => $root)),
+    dir => Path::Tiny->new(tempdir( "${name}_XXXX", DIR => $root)),
   }, $class;
 }
 
@@ -1165,7 +1190,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 2.33
+version 2.47
 
 =head1 SYNOPSIS
 
@@ -1505,8 +1530,34 @@ absolute form of C<./_alien> by default.
 The stage directory where files will be copied.  This is usually the
 root of the blib share directory.
 
+=item system_probe_class
+
+After the probe step this property may contain the plugin class that
+performed the system probe.  It shouldn't be filled in directly by
+the plugin (instead if should use the hook property C<probe_class>,
+see below).  This is optional, and not all probe plugins will provide
+this information.
+
+=item system_probe_instance_id
+
+After the probe step this property may contain the plugin instance id that
+performed the system probe.  It shouldn't be filled in directly by
+the plugin (instead if should use the hook property C<probe_instance_id>,
+see below).  This is optional, and not all probe plugins will provide
+this information.
+
 =back
 
+=head2 plugin_instance_prop
+
+ my $href = $build->plugin_instance_prop($plugin);
+
+This returns the private plugin instance properties for a given plugin.
+This method should usually only be called internally by plugins themselves
+to keep track of internal state.  Because the content can be used arbitrarily
+by the owning plugin because it is private to the plugin, and thus is not
+part of the L<Alien::Build> spec.
+
 =head2 runtime_prop
 
  my $href = $build->runtime_prop;
@@ -1640,6 +1691,20 @@ Probe and PkgConfig plugins I<may> set this property indicating the
 version of the alienized package.  Not all plugins and configurations
 may be able to provide this.
 
+=item probe_class (probe)
+
+Probe and PkgConfig plugins I<may> set this property indicating the
+plugin class that made the probe.  If the probe results in a system
+install this will be propagated to C<system_probe_class> for later
+use.
+
+=item probe_instance_id (probe)
+
+Probe and PkgConfig plugins I<may> set this property indicating the
+plugin instance id that made the probe.  If the probe results in a
+system install this will be propagated to C<system_probe_instance_id>
+for later use.
+
 =back
 
 =head1 METHODS
@@ -1747,11 +1812,28 @@ Under a C<system> install this does not do anything.
 =head2 fetch
 
  my $res = $build->fetch;
- my $res = $build->fetch($url);
+ my $res = $build->fetch($url, %options);
 
 Fetch a resource using the fetch hook.  Returns the same hash structure
 described below in the hook documentation.
 
+[version 2.39]
+
+As of L<Alien::Build> 2.39, these options are supported:
+
+=over 4
+
+=item http_headers
+
+ my $res = $build->fetch($url, http_headers => [ $key1 => $value1, $key2 => $value 2, ... ]);
+
+Set the HTTP request headers on all outgoing HTTP requests.  Note that not all
+protocols or fetch plugins support setting request headers, but the ones that
+do not I<should> issue a warning if you try to set request headers and they
+are not supported.
+
+=back
+
 =head2 decode
 
  my $decoded_res = $build->decode($res);
@@ -2111,7 +2193,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -2129,6 +2211,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
